@@ -199,6 +199,8 @@ class HistStack(object):
                 self.add(hist)
     def __getitem__(self, index):
         return self.hists[index]
+    def show_titles(self, replace=None):
+        self.hists[-1].show_titles(replace=replace)
     def add(self, hist, **kwargs):
         """
         Add a Hist object to this stack.
@@ -211,8 +213,6 @@ class HistStack(object):
             del kwargs['label']
         self.hists.append(hist)
         self.kwargs.append(kwargs)
-    def show_titles(self, replace=None):
-        self.hists[-1].show_titles(replace=replace)
     def hist(self, replace=None, **kwargs):
         """
         Make a matplotlib hist plot, with all Hists in the stack overlaid.
@@ -220,6 +220,7 @@ class HistStack(object):
         Any additional keyword arguments will be passed to pyplot.hist.  You
         will probably want to include an transparency value (i.e. alpha=0.5).
         """
+        _load_pyplot()
         contents = np.dstack([hist.y for hist in self.hists])
         xedges = self.hists[0].xedges
         x = np.dstack([hist.x for hist in self.hists])
@@ -259,7 +260,7 @@ class HistStack(object):
             all_kwargs = copy.copy(kwargs)
             all_kwargs.update(self.kwargs[i])
             errorbar = hist.errorbar(replace=replace, **all_kwargs)
-            plot.append(errorbar)
+            plots.append(errorbar)
         return plots
     def bar(self, replace=None, **kwargs):
         """
