@@ -4,10 +4,10 @@ Draw histograms to image files, specifying options on the command line.
 
 You can overlay plots from multiple ROOT files with identical structure.
 """
-__version__ = '1.2'
+__version__ = '1.3'
 
 ## Created by Jeff Klukas (klukas@wisc.edu), November 2009
-## Updated February 2010
+## Updated March 2010
 
 ######## Import python libraries #############################################
 
@@ -36,8 +36,10 @@ if '-h' not in sys.argv and len(sys.argv) > 1:
 
 class RootFile:
     """A wrapper for TFiles, allowing quick access to the name and Get."""
-    def __init__(self, file_name):
-        self.name = file_name[0:-5]
+    def __init__(self, file_name, name=None):
+        self.name = name
+        if name == None:
+            self.name = file_name[:-5]
         self.file = ROOT.TFile(file_name, 'read')
         if self.file.IsZombie():
             print "Error opening %s, exiting..." % file_name
@@ -166,11 +168,15 @@ def process_hist(path, new_path, files, obj):
     #### Combine hists in a THStack and draw
     pads = [canvas]
     stack = ROOT.THStack('st%.3i' % counter, title)
-    legend_height = 0.04 * len(files) + 0.02
+    legend_height = min(options.legend_entry_height * len(files) + 0.02,
+                        options.max_legend_height)
     if options.legend == 1:
-        legend_loc = [0.65, 0.89 - legend_height, 0.87, 0.89]
+        legend_loc = [0.87 - options.legend_width, 0.89 - legend_height,
+                      0.87, 0.89]
     elif options.legend == 8:
         legend_loc = [0.22, 0.15, 0.90, 0.15 + legend_height]
+    elif options.legend == 'None':
+        legend_loc = [0,0,0,0]
     else:
         print "Invalid legend parameter for ROOT output!"
         sys.exit(1)
@@ -252,6 +258,11 @@ def process_hist_matplotlib(path, new_path, files, obj):
         stack.barstack(replace=options.replace)
     if options.bar:
         stack.bar(replace=options.replace, alpha=0.5)
+    if options.hist:
+        mycolors = [(r,g,b,1.) for r,g,b in options.colors[:len(files)]]
+        stack.hist(replace=options.replace, alpha=0.5,
+                   # TODO: figure out how to pass a sequence to 'color'
+                   histtype='stepfilled')
     if options.efficiency:
         plt.ylim(0, 1)
     if options.logx: ax.set_xscale('log')
@@ -259,7 +270,9 @@ def process_hist_matplotlib(path, new_path, files, obj):
     if options.numbering:
         plt.text(0.98, 0.98, counter, transform=plt.figure(1).transFigure,
                  size="small", ha='right', va='top')
-    plt.legend(numpoints=1, loc=options.legend)
+    stack.show_titles(replace=options.replace)
+    if options.legend != 'None':
+        plt.legend(numpoints=1, loc=options.legend)
     output_file_name = '%s/%s/%s' % (options.plot_dir, path, name)
     plt.savefig(output_file_name, transparent=options.transparent)
     if options.ext == "pdf":
@@ -282,7 +295,7 @@ def save_plot(stack, plot_dir, path, name, counter):
 def report_progress(counter, divisor=1):
     """Print the current number of finished plots."""
     if counter % divisor == 0:
-        print "\r%i plots written to %s" % (counter, options.output),
+        print "\r%i plots written to %s/" % (counter, options.output),
         sys.stdout.flush()
 
 def merge_pdf():
@@ -377,7 +390,7 @@ def wilson(numerator, denominator):
         down.append(eff[i] - (1/(1 + 1/n) * (eff[i] + 1/(2*n) - sqrt)))
     return eff, up, down
 
-def add_options_from_configuration(options, nfiles):
+def add_options_from_configuration(options):
     """Define a set of global variables storing style information"""
     def append_to_options(config, options):
         for attribute in dir(config):
@@ -386,17 +399,20 @@ def add_options_from_configuration(options, nfiles):
                 setattr(options, attribute, attr)
         return options
     try:
-        from root2matplot import overlayHists_config
-        options = append_to_options(overlayHists_config, options)
-    except: pass
-    try:
-        import overlayHists_config
-        options = append_to_options(overlayHists_config, options)
-    except: pass
+        from root2matplot import overlayHists_config as default_config
+        options = append_to_options(default_config, options)
+    except ImportError:
+        pass
+    sys.path.insert(0, '')
+    for f in options.config_files:
+        user_config = __import__(f[:-3])
+        options = append_to_options(user_config, options)
     return options
 
-def process_options(options, nfiles):
-    options.use_matplotlib = (options.stack or options.errorbar or options.bar)
+def process_options(options):
+    nfiles = len(options.filenames)
+    options.use_matplotlib = (options.stack or options.errorbar or
+                              options.bar or options.hist)
     try:
         global matplotlib
         import matplotlib
@@ -458,12 +474,15 @@ Documentation: http://packages.python.org/root2matplot/
 Function: overlays corresponding histograms from several files, dumping the
   images into a directory structure that mirrors that of the ROOT file and,
   if output format is pdf, also merging all images into a single file;
-  most style options can be controlled from your rootlogon.C macro
+  most style options can be controlled from your rootlogon.C macro; advanced
+  operation using configuration files is described in the full online
+  documentation.
 
 Note: By default, this script will work completely in ROOT.  If you use the
-  options 'bar', 'errorbar', or 'stack', output will be produced in matplotlib.
-  More complex style attributes like colors and markers used can be configured
-  by placing an overlayHists_config.py in your current directory."""
+  options 'bar', 'errorbar', 'hist', or 'stack', output will be produced in
+  matplotlib.  More complex style attributes like colors and markers used can
+  be configured by including a python configuration file in the command-line
+  arguments."""
     
     parser = optparse.OptionParser(usage=usage, 
                                    version='%s %s' % ('%prog', __version__))
@@ -501,6 +520,8 @@ Note: By default, this script will work completely in ROOT.  If you use the
                       help="output a matplotlib errorbar graph")
     parser.add_option('--bar', action="store_true", default=False,
                       help="output a matplotlib bar graph")
+    parser.add_option('--hist', action="store_true", default=False,
+                      help="output a matplotlib hist graph")
     group3.add_option('--transparent', action="store_true", default=False,
                       help="use a transparent background for matplotlib "
                       "output")
@@ -510,10 +531,11 @@ Note: By default, this script will work completely in ROOT.  If you use the
     parser.add_option('--ncolors', type=int, default=None,
                       help="The number of colors with which to divide the "
                       "colormap")
-    parser.add_option('--legend', type=int, default=1, metavar="LOC",
+    parser.add_option('--legend', default=1, metavar="LOC",
                       help="Place legend in LOC, according to matplotlib "
                       "location codes; for ROOT, you can use 1 (default) for "
-                      "upper right or 8 for lower center")
+                      "upper right or 8 for lower center; "
+                      "use 'None' to not show the legend")
     group3.add_option('--size', default='6x4.5',
                       help="Define the size of the matplotlib plot as "
                       "width x height in inches; default is '6x4.5'")
@@ -523,12 +545,8 @@ Note: By default, this script will work completely in ROOT.  If you use the
                       help="Replace the x-axis label with XLABEL")
     parser.add_option('--ylabel', default=None,
                       help="Replace the y-axis label with YLABEL")
-##     parser.add_option('--config', default=None,
-##                       help="Use the given style configuration file; default "
-##                       "styles are taken from overlayHists_config.py in the "
-##                       "root2matplot distribution or the current directory")
     parser.add_option('--efficiency-from', default=None, metavar="DENOM",
-                      help="Divide all plots by the hitsogram in path DENOM")
+                      help="Divide all plots by the histogram in path DENOM")
     group1 = optparse.OptionGroup(
         parser,
         "special plotting options",
@@ -565,14 +583,30 @@ Note: By default, this script will work completely in ROOT.  If you use the
     options, arguments = parser.parse_args()
     options.plot_dir = '%s/%s' % (os.path.abspath('.'), options.output)
     options.regex = re.compile(options.path)
-    files = [RootFile(filename) for filename in arguments]
-    ## if no arguments provided, just display the help message
+    for arg in arguments:
+        if arg[-5:] != ".root" and arg[-3:] != ".py":
+            raise TypeError("Arguments must be root files "
+                            "or python configurations!")
+    options.config_files = [x for x in arguments if x[-3:] == ".py"]
+    filenames_from_interface = [x for x in arguments if x[-5:] == ".root"]
+    ## add style options and create the canvas
+    options = add_options_from_configuration(options)
+    if "filenames" in dir(options):
+        if filenames_from_interface:
+            print "Warning: filenames parameter defined in configuration;"
+            print "         filenames on the command line will be ignored."
+    else:
+        options.filenames = filenames_from_interface
+    try:
+        files = [RootFile(filename) for filename in options.filenames]
+    except TypeError:
+        files = [RootFile(filename, displayname) for filename, displayname
+                 in options.filenames]
+    ## if no filenames provided, just display the help message
     if len(files) == 0:
         parser.print_help()
         sys.exit(0)
-    ## add style options and create the canvas
-    options = add_options_from_configuration(options, len(files))
-    options = process_options(options, len(files))
+    options = process_options(options)
     global canvas
     canvas = ROOT.TCanvas()
     ## here, we decend into the files to start plotting
